// Request data by IRWIN ID //

function getDataByIrwinId(layerURL, irwinId) {
    let fieldsArray = ['IncidentName', 'FireCode','FSJobCode', 'POOState', 'POOCounty', 'FireDiscoveryDateTime'];
	// Output value.  Initially set to an empty string (XLSForm null)
	let outValue = "";

	// Check to make sure both layerURL and location are provided
	if (layerURL == null || layerURL === "" || irwinId == null || irwinId === "" || fieldsArray == null || fieldsArray.length === 0)  {
		// The function can't go forward; exit with the empty value
        console.log(`Missing or invalid parameters.`)
        return;
    }
    
    // Set up query parameters    
    //where IrwinId - encoded with SQL where clause
    let id = `where=` + encodeURIComponent(`IRWINID = '${irwinId}'`).replace(/'/g, '%27');
	let geometryType = "geometryType=esriGeometryPoint";
	let outFields = `outFields=` + fieldsArray.join(`%2C+`);
    let returnGeometry = "returnGeometry=true";
    let featureEncoding = "featureEncoding=esriDefault";
    let f = "f=pjson";
    let parameters = [id,geometryType,outFields,returnGeometry,featureEncoding,f].join("&");
    // put everything together
	let url = `${layerURL}/query?${parameters}`;
    console.log(`url is: ${url}`)
    
    // Create the request object
	let xhr = new XMLHttpRequest();
	// Make the request.  Note the 3rd parameter, which makes this a synchronous request
	xhr.open("GET", url, false);
    xhr.send();
    
    // Process the result
    	// This an abbreviated version without being able to distinguish different types of errors
	if (xhr.status === 200) {
        let response = JSON.parse(xhr.responseText);
        if (response.features[0]) {
            outValue = response.features[0];
            let outLonLat = MetersToLatLon(outValue.geometry.x, outValue.geometry.y)
            outValue.geometry.geopointCoords = outLonLat;
            outValue = JSON.stringify(outValue);
            return outValue;
        }
	} else {
        console.log('request failed');
        return;
    }
}

//////////////////////////////

//// Convert EPSG:3857 to lat/lon for Survey123 geopoint
function MetersToLatLon(x, y) {
    const PI = Math.PI;
    // Converts XY point from Spherical Mercator EPSG:900913 to lat/lon in WGS84 Datum
     // Fuente: http://www.maptiler.org/google-maps-coordinates-tile-bounds-projection/
    var originShift = 2.0 * PI * 6378137.0 / 2.0;

    var lon = (x / originShift) * 180.0;
    var lat = (y / originShift) * 180.0;

    lat = 180.0 / PI * (2.0 * Math.atan( Math.exp( lat * PI / 180.0)) - PI / 2.0);
    let coordString = `${lat} ${lon}`;
    return coordString;
}

//////////////////////////////




/// MAKE THIS JUST ONE FIELD FOR TESTING
function getTestIrwinData(layerURL, irwinId) {
    let field = 'IncidentName';
	// Output value.  Initially set to an empty string (XLSForm null)
	let outValues = "";

	// Check to make sure both layerURL and location are provided
	if (layerURL == null || layerURL === "" || irwinId == null || irwinId === "" || field == null || field === '')  {
		// The function can't go forward; exit with the empty value
        console.log(`Missing or invalid parameters.`)
        return;
    }
    
    // Set up query parameters
    
    //where IrwinId - encoded with SQL where clause
    let id = `where=` + encodeURIComponent(`IRWINID = '${irwinId}'`).replace(/'/g, '%27');
    console.log(id)
	let geometryType = "geometryType=esriGeometryPoint";
	let outFields = `outFields=${field}`;
    let returnGeometry = "returnGeometry=true";
    let featureEncoding = "featureEncoding=esriDefault";
    //format - get geojson
    let f = "f=pjson";
    
	let parameters = [id,geometryType,outFields,returnGeometry,featureEncoding,f].join("&");
    // put everything together
	let url = `${layerURL}/query?${parameters}`;
    console.log(`url is: ${url}`)
    // Create the request object
	let xhr = new XMLHttpRequest();
	// Make the request.  Note the 3rd parameter, which makes this a synchronous request
	xhr.open("GET", url, false);
    xhr.send();
    
    // Process the result
    	// This an abbreviated version without being able to distinguish different types of errors
	if (xhr.status === 200) {
        let response = JSON.parse(xhr.responseText);
        if (response.features[0]) {
            console.log(response.features[0]);
            //outValues = response.features[0];
			outValues = JSON.stringify(response.features[0]);
            return outValues;
        }
	} else {
        console.log('request failed');
        return;
    }
}